@@ -3,34 +3,19 @@ Module containing utilities for the data.
 
 """
 
-import importlib
 import warnings
+
+import metpy
 import numpy as np
 import pint
 import scipy.stats as stats
 import xarray as xr
 
-spec = importlib.util.find_spec('pyart')
-if spec is not None:
-    PYART_AVAILABLE = True
-else:
-    PYART_AVAILABLE = False
-
 try:
-    import metpy
-    from pkg_resources import DistributionNotFound
-
-    METPY_AVAILABLE = True
+    import pyart
+    PYART_AVAILABLE = True
 except ImportError:
-    METPY_AVAILABLE = False
-except (ModuleNotFoundError, DistributionNotFound):
-    warnings.warn(
-        'MetPy is installed but could not be imported. '
-        + 'Please check your MetPy installation. Some features '
-        + 'will be disabled.',
-        ImportWarning,
-    )
-    METPY_AVAILABLE = False
+    PYART_AVAILABLE = False
 
 
 @xr.register_dataset_accessor('utils')
@@ -600,8 +585,6 @@ def create_pyart_obj(
         raise ImportError(
             'Py-ART needs to be installed on your system to convert to ' 'Py-ART Object.'
         )
-    else:
-        import pyart
     # Get list of variables if none provided
     if variables is None:
         variables = list(obj.keys())
@@ -787,12 +770,6 @@ def convert_to_potential_temp(
     doi:10.5065/D6WW7G29.
 
     """
-
-    if not METPY_AVAILABLE:
-        raise ImportError(
-            'MetPy needs to be installed on your system to ' 'convert to potential temperature'
-        )
-
     potential_temp = None
     if temp_var_units is None and temp_var_name is not None:
         temp_var_units = obj[temp_var_name].attrs['units']
@@ -886,12 +863,6 @@ def height_adjusted_temperature(
     doi:10.5065/D6WW7G29.
 
     """
-
-    if not METPY_AVAILABLE:
-        raise ImportError(
-            'MetPy needs to be installed on your system to ' 'convert temperature for height.'
-        )
-
     adjusted_temperature = None
     if temp_var_units is None and temperature is None:
         temp_var_units = obj[temp_var_name].attrs['units']
@@ -934,7 +905,6 @@ def height_adjusted_pressure(
     pressure=None,
     press_var_units=None,
 ):
-
     """
     Converts pressure for change in height.
 
@@ -972,13 +942,6 @@ def height_adjusted_pressure(
     doi:10.5065/D6WW7G29.
 
     """
-
-    if not METPY_AVAILABLE:
-        raise ImportError(
-            'MetPy needs to be installed on your system to '
-            'convert to convert pressure for change in height.'
-        )
-
     adjusted_pressure = None
     if press_var_units is None and pressure is None:
         press_var_units = obj[press_var_name].attrs['units']
